@@ -352,26 +352,26 @@ class Experiment(EntityPrimary):
 
         return experimentSignatureRequestRepository.newExperimentSignatureRequest(self.__user__, self.id, user_id=user_id, message=message)
 
-    def getMaterials(self):
+    def getInventoryFields(self):
         """
-        Returns a list of the materials in the Experiment.
+        Returns a list of the inventory fields in the Experiment.
 
         Returns
         -------
-        List[:class:`~labstep.entities.experimentMaterial.model.ExperimentMaterial`]
-            List of the materials in an Experiment.
+        List[:class:`~labstep.entities.experimentInventoryField.model.ExperimentInventoryField`]
+            List of the inventory fields in an Experiment.
 
         Example
         -------
         ::
 
             experiment = user.getExperiment(17000)
-            exp_materials = experiment.getMaterials()
-            print(exp_materials[0])
+            exp_inventory_fields = experiment.getInventoryFields()
+            print(exp_inventory_fields[0])
         """
-        return self.root_experiment.getMaterials()
+        return self.root_experiment.getInventoryFields()
 
-    def addMaterial(
+    def addInventoryField(
         self,
         name=UNSPECIFIED,
         amount=UNSPECIFIED,
@@ -381,12 +381,12 @@ class Experiment(EntityPrimary):
         extraParams={},
     ):
         """
-        Add a new material to the Experiment.
+        Add a new inventory field to the Experiment.
 
         Parameters
         ----------
         name (str)
-            The name of the material to add.
+            The name of the inventory field to add.
         amount (str)
             The amount used.
         units (str)
@@ -399,8 +399,8 @@ class Experiment(EntityPrimary):
 
         Returns
         -------
-        :class:`~labstep.entities.experimentMaterial.model.ExperimentMaterial`
-            The newly added material entity.
+        :class:`~labstep.entities.experimentInventoryField.model.ExperimentInventoryField`
+            The newly added inventory field entity.
 
         Example
         -------
@@ -408,15 +408,15 @@ class Experiment(EntityPrimary):
 
             experiment = user.getExperiment(17000)
             resource = user.getResources(search_query='Sample A')[0]
-            experiment.addMaterial(name='Sample A', amount='2', units='ml',
+            experiment.addInventoryField(name='Sample A', amount='2', units='ml',
                                  resource_id=resource.id)
         """
-        return self.root_experiment.addMaterial(name=name,
-                                                resource_id=resource_id,
-                                                resource_item_id=resource_item_id,
-                                                amount=amount,
-                                                units=units,
-                                                extraParams=extraParams)
+        return self.root_experiment.addInventoryField(name=name,
+                                                      resource_id=resource_id,
+                                                      resource_item_id=resource_item_id,
+                                                      amount=amount,
+                                                      units=units,
+                                                      extraParams=extraParams)
 
     def addToCollection(self, collection_id):
         """
@@ -641,3 +641,11 @@ class Experiment(EntityPrimary):
     @deprecated(version='3.3.2', reason="You should use experiment.getDataFields instead")
     def getDataElements(self):
         return self.getDataFields()
+
+    @deprecated(version='3.12.0', reason="You should use getInventoryFields instead")
+    def getMaterials(self, *args, **kwargs):
+        return self.getInventoryFields(*args, **kwargs)
+
+    @deprecated(version='3.12.0', reason="You should use addInventoryField instead")
+    def addMaterial(self, *args, **kwargs):
+        return self.addInventoryField(*args, **kwargs)
